@@ -6,9 +6,19 @@
 
 
 setMethod('predict', signature(object='GeographicDistance'), 
-	function(object, x, ext=NULL, filename='', mask=FALSE, progress='text', ...) {
+	function(object, x, ext=NULL, filename='', mask=FALSE, progress='text', fun=NULL, ...) {
 	
-		inverse = function(x) { x[x>0] <- 1/x[x>0]; return(x) }
+		if (is.null(fun)) {
+			inverse <- function(x) {
+				x[x < 1] <- 1
+				1/x
+			}
+		} else {
+			inverse <- function(x) {
+				x[x < 1] <- 1
+				fun(1/x)
+			}
+		}
 
 		if ( extends(class(x), 'Raster'))  {
 			if (! mask) {
@@ -28,11 +38,13 @@ setMethod('predict', signature(object='GeographicDistance'),
 			
 		} else {
 		
-			if ( inherits(x, 'SpatialPoints') )  { x = coordinates(x) }
+			if ( inherits(x, 'SpatialPoints') )  { 
+				x = coordinates(x) 
+			}
 			
 			res <- vector(length=nrow(x))
 			for (i in 1:nrow(x)) {
-				res[i] <- min( pointDistance(x[i,], object@presence) )
+				res[i] <- min( pointDistance(x[i,], object@presence, longlat=object@lonlat) )
 			}	
 			return(inverse(res))
 		}
